import json
import random

def readJson(filename):
    with open(filename, mode='r',encoding="utf-8") as file:
        return json.loads(file.read())


def produceComments(_type="好评", _class="鞋子", filename="data.json"):
    """
    :param _type: 好评 或者 差评
    :param _class: 商品类目，例如：鞋子
    """
    try:
        data = readJson(filename)
        comments = data[_type]
        return (random.choice(comments["开始"]) + random.choice(comments["中间"]) + random.choice(comments["结束"])).replace("$", _class)
    except Exception as e:
        print("{} 文件找不到，请放在main的同目录下！".format(e))
    

if __name__ == "__main__":
    produceComments(_type="好评", _class="手机")


from distutils.core import setup


setup(
    name='GBComments',
    version='0.0.5',
    py_modules=['GBComments'],
    author="WRAllen",
    author_email="1072274105@qq.com",
    # 这里会在他人搜索时显示
    description="用于生成好评差评的库",
    # github地址
    url='https://github.com/WRAllen/GBComments'
)